@@ -1,4 +1,4 @@
-DEV = True
+DEV = False
 import typer
 import os
 
